@@ -2,10 +2,12 @@
 #include <QDebug>
 
 SwipeCounter::SwipeCounter(){
+   
+    this->setFixedSize(200,100);
     swipes = set.value("swipes",0).toInt();
     dist = swipes*7.6;
     QVBoxLayout *lay  = new QVBoxLayout;
-    conf = new GConfItem("/apps/osso/hildon-desktop/views/current",this);
+    conf = new GConfItem("/apps/osso/hildon-desktop/views/current");
     connect(conf,SIGNAL(valueChanged()),this,SLOT(desktopChanged()));
     count = new QLabel(this);
     count->setText("Swipes: " +QString::number(swipes));
@@ -20,11 +22,9 @@ SwipeCounter::SwipeCounter(){
     lay->addWidget(count);
     lay->addWidget(distance);
     lay->setAlignment(Qt::AlignCenter);
-    this->setLayout(lay);
+    setLayout(lay);
     setAttribute(Qt::WA_TranslucentBackground);
-    this->setFixedSize(200,100);
-    show();
-}
+   }
 void SwipeCounter::showSettingsDialog(){
 }
 
