@@ -9,7 +9,7 @@
 #include <QVBoxLayout>
 #include <GConfItem>
 #include <QSettings>
-class SwipeCounter : public QDialog
+class SwipeCounter : public QWidget
 {
     Q_OBJECT
 
